fn breakpoint<FEN: FoundryEvmNetwork>(
state: &mut Cheatcodes<FEN>,
caller: &Address,
s: &str,
add: bool,
) -> ResultExpand description
Adds or removes the given breakpoint to the state.
fn breakpoint<FEN: FoundryEvmNetwork>(
state: &mut Cheatcodes<FEN>,
caller: &Address,
s: &str,
add: bool,
) -> ResultAdds or removes the given breakpoint to the state.